package eu.etaxonomy.taxeditor.molecular.editor;


import org.eclipse.swt.widgets.Event;
import org.eclipse.swt.widgets.Listener;
import org.eclipse.ui.PlatformUI;
import org.eclipse.ui.actions.ActionFactory;
import org.eclipse.ui.commands.ICommandService;

import eu.etaxonomy.taxeditor.molecular.handler.AbstractAlignmentEditorHandler;
import info.bioinfweb.libralign.alignmentarea.selection.SelectionChangeEvent;
import info.bioinfweb.libralign.alignmentarea.selection.SelectionListener;



/**
 * Listener used to update copy/paste events associated with {@link AlignmentEditor}.
 * 
 * @author Ben Stöver
 * @date 25.08.2015
 */
public class AlignmentEditorActionUpdater implements SelectionListener, Listener {
	private static final String[] IDS = {ActionFactory.COPY.getCommandId(), ActionFactory.CUT.getCommandId(), 
		ActionFactory.PASTE.getCommandId()};
	
	
	private void updateEvents() {
		ICommandService service = (ICommandService)PlatformUI.getWorkbench().getService(ICommandService.class);
		for (int i = 0; i < IDS.length; i++) {
	        service.refreshElements(IDS[i], null);
		}
	}
	
	
	@Override
	public void handleEvent(Event event) {
		AlignmentEditor editor = AbstractAlignmentEditorHandler.getActiveAlignmentEditor();
		if (editor != null) {
            updateEvents();
		}
	}

	
	@Override
	public void selectionChanged(SelectionChangeEvent e) {
		AlignmentEditor editor = AbstractAlignmentEditorHandler.getActiveAlignmentEditor();
		if (editor != null) {
			if ((e.getSource() == editor.getReadsArea().getSelection()) || 
					(e.getSource() == editor.getEditableConsensusArea().getSelection())) {
				
				updateEvents();
			}
		}
	}
}
