/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.molecular.handler;


import java.util.Map;

import org.eclipse.core.commands.ExecutionEvent;
import org.eclipse.core.commands.ExecutionException;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.ui.PlatformUI;
import org.eclipse.ui.commands.ICommandService;
import org.eclipse.ui.commands.IElementUpdater;
import org.eclipse.ui.menus.UIElement;

import eu.etaxonomy.taxeditor.model.AbstractUtility;
import eu.etaxonomy.taxeditor.molecular.editor.AlignmentEditor;
import eu.etaxonomy.taxeditor.molecular.l10n.Messages;



/**
 * Switches an {@link AlignmentEditor} between insertion and overwrite mode.
 *
 * @author Ben Stöver
 * @date 04.12.2014
 */
public class ToggleInsertOverwriteHandler extends AbstractAlignmentEditorHandler implements IElementUpdater {
	public static final String COMMAND_ID =
			"eu.etaxonomy.taxeditor.molecular.AlignmentEditor.toggleInsertOverwrite"; //$NON-NLS-1$


    private final ImageDescriptor INSERT_DESCRIPTOR = HandlerTools.createImageDescriptor("insert-16x16.png"); //$NON-NLS-1$
    private final ImageDescriptor OVERWRITE_DESCRIPTOR = HandlerTools.createImageDescriptor("overwrite-16x16.png"); //$NON-NLS-1$


    @Override
    public void doExecute(ExecutionEvent event, AlignmentEditor editor) throws ExecutionException {
        editor.toggleInsertOverwrite();
    }


	@Override
	public void updateElement(UIElement element, @SuppressWarnings("rawtypes") Map parameters) {
	    Object activeEditor = AbstractUtility.getActiveE4Editor();
		if (activeEditor instanceof AlignmentEditor) {
			if (((AlignmentEditor)activeEditor).isInsertMode()) {
			    element.setIcon(INSERT_DESCRIPTOR);
				element.setText("INS"); //$NON-NLS-1$
				element.setTooltip(Messages.ToggleInsertOverwriteHandler_SWITCH_OVERWRITE);
			}
			else {
                element.setIcon(OVERWRITE_DESCRIPTOR);
				element.setText("OVR"); //$NON-NLS-1$
				element.setTooltip(Messages.ToggleInsertOverwriteHandler_SWITCH_INSERTION);
			}
            PlatformUI.getWorkbench().getService(ICommandService.class).refreshElements(
                    ToggleLeftRightInsertionHandler.COMMAND_ID, null);
		}
	}
}
