// $Id$
/**
* Copyright (C) 2016 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.molecular.io;


import info.bioinfweb.commons.io.XMLUtils;
import info.bioinfweb.jphyloio.ReaderStreamDataProvider;
import info.bioinfweb.jphyloio.WriterStreamDataProvider;
import info.bioinfweb.jphyloio.objecttranslation.InvalidObjectSourceDataException;
import info.bioinfweb.jphyloio.objecttranslation.implementations.AbstractXMLObjectTranslator;

import java.io.IOException;

import javax.xml.stream.XMLEventReader;
import javax.xml.stream.XMLStreamException;
import javax.xml.stream.XMLStreamWriter;

import eu.etaxonomy.cdm.model.molecular.SingleReadAlignment;
import eu.etaxonomy.taxeditor.molecular.l10n.Messages;



/**
 * <i>JPhyloIO</i> object translator to read and write a shift list of a {@link SingleReadAlignment} object from and
 * to <i>XML</i>.
 *
 * @author Ben Stöver
 * @date 28.10.2016
 */
public class CDMPherogramAlignmentObjectTranslator extends AbstractXMLObjectTranslator<SingleReadAlignment.Shift[]>
        implements SingleReadAlignmentRDFXMLConstants {

    @Override
    public Class<SingleReadAlignment.Shift[]> getObjectClass() {
        return SingleReadAlignment.Shift[].class;
    }


    @Override
    public SingleReadAlignment.Shift[] readXMLRepresentation(XMLEventReader reader, ReaderStreamDataProvider<?> streamDataProvider)
            throws IOException, XMLStreamException, InvalidObjectSourceDataException {

        // TODO implement
        throw new InternalError(Messages.CDMPherogramAlignmentObjectTranslator_NOT_IMPLEMENTED);
    }


    @Override
    public void writeXMLRepresentation(XMLStreamWriter writer, Object object, WriterStreamDataProvider<?> streamDataProvider)
            throws IOException, XMLStreamException, ClassCastException {

        SingleReadAlignment.Shift[] shifts = (SingleReadAlignment.Shift[])object;
        XMLUtils.writeStartElement(writer, TAG_SHIFTS);
        for (SingleReadAlignment.Shift shift : shifts) {
            XMLUtils.writeStartElement(writer, TAG_SHIFT);
            XMLUtils.writeAttribute(writer, ATTR_POSITION, Integer.toString(shift.position));
            XMLUtils.writeAttribute(writer, ATTR_SHIFT, Integer.toString(shift.shift));
            writer.writeEndElement();
        }
        writer.writeEndElement();
    }
}
