// $Id$
/**
* Copyright (C) 2016 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.molecular.io.wizard;


import org.eclipse.core.databinding.DataBindingContext;
import org.eclipse.core.databinding.validation.MultiValidator;
import org.eclipse.core.databinding.validation.ValidationStatus;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.jface.databinding.swt.ISWTObservableValue;
import org.eclipse.jface.databinding.swt.SWTObservables;
import org.eclipse.jface.databinding.wizard.WizardPageSupport;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.layout.FormAttachment;
import org.eclipse.swt.layout.FormData;
import org.eclipse.swt.layout.FormLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Text;

import eu.etaxonomy.taxeditor.molecular.l10n.Messages;



/**
 * Wizard page that allows to specify which parts of a single read alignment shall be exported to an alignment file.
 *
 * @author Ben St&ouml;ver
 * @date 18.04.2016
 */
public class ExportSingleReadAlignmentOptionsPage extends AbstractExportSingleReadAlignmentWizardPage {
    private Text consensusSequenceLabelTextField;
    private Button exportConsensusSequenceCB;
    private Button exportSingleReadsCB;
    private Button gapRadioButton;
    private Button missingDataRadioButton;
    private Button elongateSequecesCheckBox;


    /**
     * Create the wizard.
     */
    public ExportSingleReadAlignmentOptionsPage() {
        super("ExportSingleReadAlignmentOptions");  //TODO Which pageName should be used here? Any conventions? //$NON-NLS-1$
        setTitle(Messages.wizardExportAlignmentOptionsTitle);
        setDescription(Messages.wizardExportAlignmentOptionsDescription);
    }


    /**
     * Create contents of the wizard.
     *
     * @param parent the parent component
     */
    @Override
    public void createControl(Composite parent) {
        DataBindingContext dbc = new DataBindingContext();
        WizardPageSupport.create(this, dbc);

        Composite container = new Composite(parent, SWT.NULL);

        setControl(container);
        container.setLayout(new FormLayout());

        exportSingleReadsCB = new Button(container, SWT.CHECK);
        FormData fd_exportSingleReadsCB = new FormData();
        fd_exportSingleReadsCB.top = new FormAttachment(0, 40);
        fd_exportSingleReadsCB.left = new FormAttachment(0, 10);
        exportSingleReadsCB.setLayoutData(fd_exportSingleReadsCB);
        exportSingleReadsCB.setText(Messages.wizardExportAlignmentExportSingleReads);
        final ISWTObservableValue exportSingleReadsObservable = SWTObservables.observeSelection(exportSingleReadsCB);
        dbc.bindValue(exportSingleReadsObservable, getWizard().getModel().getExportSingleReadsObservable());
        exportSingleReadsCB.setSelection(false);
        exportSingleReadsCB.setSelection(true);  // Must happen after the component has been bound to the model.


        exportConsensusSequenceCB = new Button(container, SWT.CHECK);
        exportConsensusSequenceCB.addSelectionListener(new SelectionAdapter() {
            @Override
            public void widgetSelected(SelectionEvent e) {
                consensusSequenceLabelTextField.setEnabled(exportConsensusSequenceCB.getSelection());
            }
        });
        FormData fd_exportConsensusSequenceCB = new FormData();
        fd_exportConsensusSequenceCB.top = new FormAttachment(exportSingleReadsCB, 6);
        fd_exportConsensusSequenceCB.left = new FormAttachment(0, 10);
        exportConsensusSequenceCB.setLayoutData(fd_exportConsensusSequenceCB);
        exportConsensusSequenceCB.setText(Messages.wizardExportAlignmentExportConsensusSeqLabel);
        final ISWTObservableValue exportConsensusSequenceObservable = SWTObservables.observeSelection(exportConsensusSequenceCB);
        dbc.bindValue(exportConsensusSequenceObservable, getWizard().getModel().getExportConsensusSequenceObservable());
        exportConsensusSequenceCB.setSelection(false);
        exportConsensusSequenceCB.setSelection(true);  // Must happen after the component has been bound to the model.

        consensusSequenceLabelTextField = new Text(container, SWT.BORDER);
        FormData fd_consensusSequenceNameTextField = new FormData();
        fd_consensusSequenceNameTextField.bottom = new FormAttachment(exportConsensusSequenceCB, 32, SWT.BOTTOM);
        fd_consensusSequenceNameTextField.top = new FormAttachment(exportConsensusSequenceCB, 6);
        fd_consensusSequenceNameTextField.right = new FormAttachment(100, -10);
        fd_consensusSequenceNameTextField.left = new FormAttachment(0, 32);
        consensusSequenceLabelTextField.setLayoutData(fd_consensusSequenceNameTextField);
        final ISWTObservableValue consensusSequenceLabelObservable = SWTObservables.observeText(consensusSequenceLabelTextField, SWT.Modify);
        dbc.bindValue(consensusSequenceLabelObservable, getWizard().getModel().getConsensusSequenceLabelObservable());
        consensusSequenceLabelTextField.setText("Consensus"); //$NON-NLS-1$

        Label lblSpecifyTheSequences = new Label(container, SWT.NONE);
        FormData fd_lblSpecifyTheSequences = new FormData();
        fd_lblSpecifyTheSequences.top = new FormAttachment(0, 10);
        fd_lblSpecifyTheSequences.left = new FormAttachment(0, 10);
        lblSpecifyTheSequences.setLayoutData(fd_lblSpecifyTheSequences);
        lblSpecifyTheSequences.setText(Messages.wizardExportAlignmentExportedSeqHeading);

        Label lblSpecifyAdditionalExport = new Label(container, SWT.NONE);
        FormData fd_lblSpecifyAdditionalExport = new FormData();
        fd_lblSpecifyAdditionalExport.top = new FormAttachment(consensusSequenceLabelTextField, 24);
        fd_lblSpecifyAdditionalExport.left = new FormAttachment(exportSingleReadsCB, 0, SWT.LEFT);
        lblSpecifyAdditionalExport.setLayoutData(fd_lblSpecifyAdditionalExport);
        lblSpecifyAdditionalExport.setText(Messages.wizardExportAlignmentAdditionalOptionsHeading);

        elongateSequecesCheckBox = new Button(container, SWT.CHECK);
        elongateSequecesCheckBox.addSelectionListener(new SelectionAdapter() {
            @Override
            public void widgetSelected(SelectionEvent e) {
                missingDataRadioButton.setEnabled(elongateSequecesCheckBox.getSelection());
                gapRadioButton.setEnabled(elongateSequecesCheckBox.getSelection());
            }
        });
        FormData fd_btnElongateSequecesTo = new FormData();
        fd_btnElongateSequecesTo.left = new FormAttachment(exportSingleReadsCB, 0, SWT.LEFT);
        fd_btnElongateSequecesTo.top = new FormAttachment(lblSpecifyAdditionalExport, 12);
        elongateSequecesCheckBox.setLayoutData(fd_btnElongateSequecesTo);
        elongateSequecesCheckBox.setText(Messages.wizardExportAlignmentElongateSeqHeading);
        dbc.bindValue(SWTObservables.observeSelection(elongateSequecesCheckBox), getWizard().getModel().getElongateSequencesObservable());

        missingDataRadioButton = new Button(container, SWT.RADIO);
        FormData fd_missingDataRadioButton = new FormData();
        fd_missingDataRadioButton.top = new FormAttachment(elongateSequecesCheckBox, 6);
        missingDataRadioButton.setLayoutData(fd_missingDataRadioButton);
        missingDataRadioButton.setEnabled(false);
        missingDataRadioButton.setText(Messages.wizardExportAlignmentElongateSeqMissingData);

        gapRadioButton = new Button(container, SWT.RADIO);
        fd_missingDataRadioButton.left = new FormAttachment(gapRadioButton, 80);
        FormData fd_gapRadioButton = new FormData();
        fd_gapRadioButton.top = new FormAttachment(elongateSequecesCheckBox, 6);
        fd_gapRadioButton.left = new FormAttachment(consensusSequenceLabelTextField, 0, SWT.LEFT);
        gapRadioButton.setLayoutData(fd_gapRadioButton);
        gapRadioButton.setEnabled(false);
        gapRadioButton.setSelection(true);
        gapRadioButton.setText(Messages.wizardExportAlignmentElongateSeqGap);
        dbc.bindValue(SWTObservables.observeSelection(gapRadioButton), getWizard().getModel().getUseGapTokenObservable());

        setPageComplete(true);  // Allow to finish the wizard in the previous page.

        dbc.addValidationStatusProvider(new MultiValidator() {
            @Override
            protected IStatus validate() {
                String label = (String)consensusSequenceLabelObservable.getValue();
                boolean exportConsensus = (Boolean)exportConsensusSequenceObservable.getValue();
                boolean exportReads = (Boolean)exportSingleReadsObservable.getValue();

                if (!exportConsensus && !exportReads) {
                    return ValidationStatus.error(Messages.wizardExportAlignmentErrorNothingToExport);
                }
                else if (exportConsensus && ((label == null) || label.isEmpty())) {
                    return ValidationStatus.error(Messages.wizardExportAlignmentErrorMissingSeqLabel);
                }
                else {
                    return ValidationStatus.ok();
                }
            }
        });
    }
}
